
API Documentation
=================

.. automodule:: hoshi.i18n
    :members:
    :undoc-members:
    :show-inheritance:

External Translators Integration
--------------------------------

.. toctree::

   hoshi.translators.gcloud
   hoshi.translators.base

Language Sets
-------------

.. toctree::

   hoshi.sets

Internal Utility Modules
------------------------

.. toctree::

   hoshi.translation
